==> sqslambda-1.57.0-sources.jar: software/amazon/awsconstructs/services/sqslambda/SqsToLambdaProps.java <==
package software.amazon.awsconstructs.services.sqslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.10.0 (build 27cfbed)", date = "2020-08-07T22:10:48.189Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.sqslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sqs-lambda.SqsToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(SqsToLambdaProps.Jsii$Proxy.class)
public interface SqsToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional user provided properties for the dead letter queue.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.QueueProps getDeadLetterQueueProps() {
        return null;
    }

    /**
     * Whether to deploy a secondary queue to be used as a dead letter queue.
     * <p>
     * Default: - true.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDeployDeadLetterQueue() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * Existing instance of SQS queue object, if this is set then queueProps is ignored.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.Queue getExistingQueueObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
     * <p>
     * Default: - required field if deployDeadLetterQueue=true.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxReceiveCount() {
        return null;
    }

    /**
     * Optional user provided properties.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.QueueProps getQueueProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SqsToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SqsToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<SqsToLambdaProps> {
        private software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps;
        private java.lang.Boolean deployDeadLetterQueue;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.sqs.Queue existingQueueObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private java.lang.Number maxReceiveCount;
        private software.amazon.awscdk.services.sqs.QueueProps queueProps;

        /**
         * Sets the value of {@link SqsToLambdaProps#getDeadLetterQueueProps}
         * @param deadLetterQueueProps Optional user provided properties for the dead letter queue.
         * @return {@code this}
         */
        public Builder deadLetterQueueProps(software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps) {
            this.deadLetterQueueProps = deadLetterQueueProps;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getDeployDeadLetterQueue}
         * @param deployDeadLetterQueue Whether to deploy a secondary queue to be used as a dead letter queue.
         * @return {@code this}
         */
        public Builder deployDeadLetterQueue(java.lang.Boolean deployDeadLetterQueue) {
            this.deployDeadLetterQueue = deployDeadLetterQueue;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getExistingQueueObj}
         * @param existingQueueObj Existing instance of SQS queue object, if this is set then queueProps is ignored.
         * @return {@code this}
         */
        public Builder existingQueueObj(software.amazon.awscdk.services.sqs.Queue existingQueueObj) {
            this.existingQueueObj = existingQueueObj;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getMaxReceiveCount}
         * @param maxReceiveCount The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
         * @return {@code this}
         */
        public Builder maxReceiveCount(java.lang.Number maxReceiveCount) {
            this.maxReceiveCount = maxReceiveCount;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getQueueProps}
         * @param queueProps Optional user provided properties.
         * @return {@code this}
         */
        public Builder queueProps(software.amazon.awscdk.services.sqs.QueueProps queueProps) {
            this.queueProps = queueProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SqsToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public SqsToLambdaProps build() {
            return new Jsii$Proxy(deadLetterQueueProps, deployDeadLetterQueue, existingLambdaObj, existingQueueObj, lambdaFunctionProps, maxReceiveCount, queueProps);
        }
    }

    /**
     * An implementation for {@link SqsToLambdaProps}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SqsToLambdaProps {
        private final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps;
        private final java.lang.Boolean deployDeadLetterQueue;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.sqs.Queue existingQueueObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private final java.lang.Number maxReceiveCount;
        private final software.amazon.awscdk.services.sqs.QueueProps queueProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deadLetterQueueProps = this.jsiiGet("deadLetterQueueProps", software.amazon.awscdk.services.sqs.QueueProps.class);
            this.deployDeadLetterQueue = this.jsiiGet("deployDeadLetterQueue", java.lang.Boolean.class);
            this.existingLambdaObj = this.jsiiGet("existingLambdaObj", software.amazon.awscdk.services.lambda.Function.class);
            this.existingQueueObj = this.jsiiGet("existingQueueObj", software.amazon.awscdk.services.sqs.Queue.class);
            this.lambdaFunctionProps = this.jsiiGet("lambdaFunctionProps", software.amazon.awscdk.services.lambda.FunctionProps.class);
            this.maxReceiveCount = this.jsiiGet("maxReceiveCount", java.lang.Number.class);
            this.queueProps = this.jsiiGet("queueProps", software.amazon.awscdk.services.sqs.QueueProps.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps, final java.lang.Boolean deployDeadLetterQueue, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.sqs.Queue existingQueueObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps, final java.lang.Number maxReceiveCount, final software.amazon.awscdk.services.sqs.QueueProps queueProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deadLetterQueueProps = deadLetterQueueProps;
            this.deployDeadLetterQueue = deployDeadLetterQueue;
            this.existingLambdaObj = existingLambdaObj;
            this.existingQueueObj = existingQueueObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
            this.maxReceiveCount = maxReceiveCount;
            this.queueProps = queueProps;
        }

        @Override
        public software.amazon.awscdk.services.sqs.QueueProps getDeadLetterQueueProps() {
            return this.deadLetterQueueProps;
        }

        @Override
        public java.lang.Boolean getDeployDeadLetterQueue() {
            return this.deployDeadLetterQueue;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public software.amazon.awscdk.services.sqs.Queue getExistingQueueObj() {
            return this.existingQueueObj;
        }

        @Override
        public software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public java.lang.Number getMaxReceiveCount() {
            return this.maxReceiveCount;
        }

        @Override
        public software.amazon.awscdk.services.sqs.QueueProps getQueueProps() {
            return this.queueProps;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeadLetterQueueProps() != null) {
                data.set("deadLetterQueueProps", om.valueToTree(this.getDeadLetterQueueProps()));
            }
            if (this.getDeployDeadLetterQueue() != null) {
                data.set("deployDeadLetterQueue", om.valueToTree(this.getDeployDeadLetterQueue()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getExistingQueueObj() != null) {
                data.set("existingQueueObj", om.valueToTree(this.getExistingQueueObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }
            if (this.getMaxReceiveCount() != null) {
                data.set("maxReceiveCount", om.valueToTree(this.getMaxReceiveCount()));
            }
            if (this.getQueueProps() != null) {
                data.set("queueProps", om.valueToTree(this.getQueueProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-sqs-lambda.SqsToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SqsToLambdaProps.Jsii$Proxy that = (SqsToLambdaProps.Jsii$Proxy) o;

            if (this.deadLetterQueueProps != null ? !this.deadLetterQueueProps.equals(that.deadLetterQueueProps) : that.deadLetterQueueProps != null) return false;
            if (this.deployDeadLetterQueue != null ? !this.deployDeadLetterQueue.equals(that.deployDeadLetterQueue) : that.deployDeadLetterQueue != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.existingQueueObj != null ? !this.existingQueueObj.equals(that.existingQueueObj) : that.existingQueueObj != null) return false;
            if (this.lambdaFunctionProps != null ? !this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps != null) return false;
            if (this.maxReceiveCount != null ? !this.maxReceiveCount.equals(that.maxReceiveCount) : that.maxReceiveCount != null) return false;
            return this.queueProps != null ? this.queueProps.equals(that.queueProps) : that.queueProps == null;
        }

        @Override
        public int hashCode() {
            int result = this.deadLetterQueueProps != null ? this.deadLetterQueueProps.hashCode() : 0;
            result = 31 * result + (this.deployDeadLetterQueue != null ? this.deployDeadLetterQueue.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.existingQueueObj != null ? this.existingQueueObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            result = 31 * result + (this.maxReceiveCount != null ? this.maxReceiveCount.hashCode() : 0);
            result = 31 * result + (this.queueProps != null ? this.queueProps.hashCode() : 0);
            return result;
        }
    }
}

==> sqslambda-1.64.0-sources.jar: software/amazon/awsconstructs/services/sqslambda/SqsToLambdaProps.java <==
package software.amazon.awsconstructs.services.sqslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.12.0 (build 5ddc9f2)", date = "2020-09-24T16:02:28.760Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.sqslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sqs-lambda.SqsToLambdaProps")
@software.amazon.jsii.Jsii.Proxy(SqsToLambdaProps.Jsii$Proxy.class)
public interface SqsToLambdaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Optional user provided properties for the dead letter queue.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.QueueProps getDeadLetterQueueProps() {
        return null;
    }

    /**
     * Whether to deploy a secondary queue to be used as a dead letter queue.
     * <p>
     * Default: - true.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDeployDeadLetterQueue() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * Existing instance of SQS queue object, if this is set then queueProps is ignored.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.Queue getExistingQueueObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
     * <p>
     * Default: - required field if deployDeadLetterQueue=true.
     */
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxReceiveCount() {
        return null;
    }

    /**
     * Optional user provided properties.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.QueueProps getQueueProps() {
        return null;
    }

    /**
     * Optional user provided properties for the dead letter queue.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps getSqsEventSourceProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SqsToLambdaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SqsToLambdaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<SqsToLambdaProps> {
        private software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps;
        private java.lang.Boolean deployDeadLetterQueue;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.sqs.Queue existingQueueObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private java.lang.Number maxReceiveCount;
        private software.amazon.awscdk.services.sqs.QueueProps queueProps;
        private software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps;

        /**
         * Sets the value of {@link SqsToLambdaProps#getDeadLetterQueueProps}
         * @param deadLetterQueueProps Optional user provided properties for the dead letter queue.
         * @return {@code this}
         */
        public Builder deadLetterQueueProps(software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps) {
            this.deadLetterQueueProps = deadLetterQueueProps;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getDeployDeadLetterQueue}
         * @param deployDeadLetterQueue Whether to deploy a secondary queue to be used as a dead letter queue.
         * @return {@code this}
         */
        public Builder deployDeadLetterQueue(java.lang.Boolean deployDeadLetterQueue) {
            this.deployDeadLetterQueue = deployDeadLetterQueue;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getExistingQueueObj}
         * @param existingQueueObj Existing instance of SQS queue object, if this is set then queueProps is ignored.
         * @return {@code this}
         */
        public Builder existingQueueObj(software.amazon.awscdk.services.sqs.Queue existingQueueObj) {
            this.existingQueueObj = existingQueueObj;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getMaxReceiveCount}
         * @param maxReceiveCount The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
         * @return {@code this}
         */
        public Builder maxReceiveCount(java.lang.Number maxReceiveCount) {
            this.maxReceiveCount = maxReceiveCount;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getQueueProps}
         * @param queueProps Optional user provided properties.
         * @return {@code this}
         */
        public Builder queueProps(software.amazon.awscdk.services.sqs.QueueProps queueProps) {
            this.queueProps = queueProps;
            return this;
        }

        /**
         * Sets the value of {@link SqsToLambdaProps#getSqsEventSourceProps}
         * @param sqsEventSourceProps Optional user provided properties for the dead letter queue.
         * @return {@code this}
         */
        public Builder sqsEventSourceProps(software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps) {
            this.sqsEventSourceProps = sqsEventSourceProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SqsToLambdaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public SqsToLambdaProps build() {
            return new Jsii$Proxy(deadLetterQueueProps, deployDeadLetterQueue, existingLambdaObj, existingQueueObj, lambdaFunctionProps, maxReceiveCount, queueProps, sqsEventSourceProps);
        }
    }

    /**
     * An implementation for {@link SqsToLambdaProps}
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SqsToLambdaProps {
        private final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps;
        private final java.lang.Boolean deployDeadLetterQueue;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.sqs.Queue existingQueueObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private final java.lang.Number maxReceiveCount;
        private final software.amazon.awscdk.services.sqs.QueueProps queueProps;
        private final software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deadLetterQueueProps = this.jsiiGet("deadLetterQueueProps", software.amazon.awscdk.services.sqs.QueueProps.class);
            this.deployDeadLetterQueue = this.jsiiGet("deployDeadLetterQueue", java.lang.Boolean.class);
            this.existingLambdaObj = this.jsiiGet("existingLambdaObj", software.amazon.awscdk.services.lambda.Function.class);
            this.existingQueueObj = this.jsiiGet("existingQueueObj", software.amazon.awscdk.services.sqs.Queue.class);
            this.lambdaFunctionProps = this.jsiiGet("lambdaFunctionProps", software.amazon.awscdk.services.lambda.FunctionProps.class);
            this.maxReceiveCount = this.jsiiGet("maxReceiveCount", java.lang.Number.class);
            this.queueProps = this.jsiiGet("queueProps", software.amazon.awscdk.services.sqs.QueueProps.class);
            this.sqsEventSourceProps = this.jsiiGet("sqsEventSourceProps", software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps, final java.lang.Boolean deployDeadLetterQueue, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.sqs.Queue existingQueueObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps, final java.lang.Number maxReceiveCount, final software.amazon.awscdk.services.sqs.QueueProps queueProps, final software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deadLetterQueueProps = deadLetterQueueProps;
            this.deployDeadLetterQueue = deployDeadLetterQueue;
            this.existingLambdaObj = existingLambdaObj;
            this.existingQueueObj = existingQueueObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
            this.maxReceiveCount = maxReceiveCount;
            this.queueProps = queueProps;
            this.sqsEventSourceProps = sqsEventSourceProps;
        }

        @Override
        public software.amazon.awscdk.services.sqs.QueueProps getDeadLetterQueueProps() {
            return this.deadLetterQueueProps;
        }

        @Override
        public java.lang.Boolean getDeployDeadLetterQueue() {
            return this.deployDeadLetterQueue;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public software.amazon.awscdk.services.sqs.Queue getExistingQueueObj() {
            return this.existingQueueObj;
        }

        @Override
        public software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public java.lang.Number getMaxReceiveCount() {
            return this.maxReceiveCount;
        }

        @Override
        public software.amazon.awscdk.services.sqs.QueueProps getQueueProps() {
            return this.queueProps;
        }

        @Override
        public software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps getSqsEventSourceProps() {
            return this.sqsEventSourceProps;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeadLetterQueueProps() != null) {
                data.set("deadLetterQueueProps", om.valueToTree(this.getDeadLetterQueueProps()));
            }
            if (this.getDeployDeadLetterQueue() != null) {
                data.set("deployDeadLetterQueue", om.valueToTree(this.getDeployDeadLetterQueue()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getExistingQueueObj() != null) {
                data.set("existingQueueObj", om.valueToTree(this.getExistingQueueObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }
            if (this.getMaxReceiveCount() != null) {
                data.set("maxReceiveCount", om.valueToTree(this.getMaxReceiveCount()));
            }
            if (this.getQueueProps() != null) {
                data.set("queueProps", om.valueToTree(this.getQueueProps()));
            }
            if (this.getSqsEventSourceProps() != null) {
                data.set("sqsEventSourceProps", om.valueToTree(this.getSqsEventSourceProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-sqs-lambda.SqsToLambdaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SqsToLambdaProps.Jsii$Proxy that = (SqsToLambdaProps.Jsii$Proxy) o;

            if (this.deadLetterQueueProps != null ? !this.deadLetterQueueProps.equals(that.deadLetterQueueProps) : that.deadLetterQueueProps != null) return false;
            if (this.deployDeadLetterQueue != null ? !this.deployDeadLetterQueue.equals(that.deployDeadLetterQueue) : that.deployDeadLetterQueue != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.existingQueueObj != null ? !this.existingQueueObj.equals(that.existingQueueObj) : that.existingQueueObj != null) return false;
            if (this.lambdaFunctionProps != null ? !this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps != null) return false;
            if (this.maxReceiveCount != null ? !this.maxReceiveCount.equals(that.maxReceiveCount) : that.maxReceiveCount != null) return false;
            if (this.queueProps != null ? !this.queueProps.equals(that.queueProps) : that.queueProps != null) return false;
            return this.sqsEventSourceProps != null ? this.sqsEventSourceProps.equals(that.sqsEventSourceProps) : that.sqsEventSourceProps == null;
        }

        @Override
        public int hashCode() {
            int result = this.deadLetterQueueProps != null ? this.deadLetterQueueProps.hashCode() : 0;
            result = 31 * result + (this.deployDeadLetterQueue != null ? this.deployDeadLetterQueue.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.existingQueueObj != null ? this.existingQueueObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            result = 31 * result + (this.maxReceiveCount != null ? this.maxReceiveCount.hashCode() : 0);
            result = 31 * result + (this.queueProps != null ? this.queueProps.hashCode() : 0);
            result = 31 * result + (this.sqsEventSourceProps != null ? this.sqsEventSourceProps.hashCode() : 0);
            return result;
        }
    }
}
